@@ -98,6 +98,35 @@ pub fn use_window_height(cx: &ScopeState) -> &UseWindowHeight {
     UseWindowBuilder::default().use_height(cx)
 }
 
+/// hooks for window's layout
+///
+/// # Arguments
+///
+/// returns: [`WindowLayout`]
+///
+/// # Examples
+///
+/// ```
+/// use dioxus::prelude::*;
+/// use dioxus_use_window::{ResponsiveLayout, use_window_layout};
+///
+/// fn App(cx: Scope) -> Element {
+///     let layout = use_window_layout::<ResponsiveLayout>(&cx);
+///
+///     cx.render(rsx!(
+///         h1 { "Window layout: {layout}" }
+///     ))
+/// }
+/// ```
+#[inline]
+pub fn use_window_layout<T>(cx: &ScopeState) -> &UseWindowLayout<T>
+where
+    T: From<usize>,
+    T: 'static,
+{
+    UseWindowBuilder::default().use_layout(cx)
+}
+
 /// hooks for window's layout
 ///
 /// # Arguments
